==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/android/createandroidmanifestwizard.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/
#ifndef CREATEANDROIDMANIFESTWIZARD_H
#define CREATEANDROIDMANIFESTWIZARD_H

#include <utils/pathchooser.h>
#include <utils/wizard.h>

QT_BEGIN_NAMESPACE
class QComboBox;
QT_END_NAMESPACE

namespace ProjectExplorer { class Target; }
namespace QmakeProjectManager { class QmakeProFileNode; }

namespace Android {
namespace Internal {

class CreateAndroidManifestWizard;

class NoApplicationProFilePage : public QWizardPage
{
    Q_OBJECT
public:
    NoApplicationProFilePage(CreateAndroidManifestWizard *wizard);
private:
    CreateAndroidManifestWizard *m_wizard;
};

class ChooseProFilePage : public QWizardPage
{
    Q_OBJECT
public:
    ChooseProFilePage(CreateAndroidManifestWizard *wizard, const QList<QmakeProjectManager::QmakeProFileNode *> &nodes);
private slots:
    void nodeSelected(int index);
private:
    CreateAndroidManifestWizard *m_wizard;
    QComboBox *m_comboBox;
};

class ChooseDirectoryPage : public QWizardPage
{
    Q_OBJECT
public:
    ChooseDirectoryPage(CreateAndroidManifestWizard *wizard);
private:
    CreateAndroidManifestWizard *m_wizard;
    Utils::PathChooser *m_androidPackageSourceDir;
};

class CreateAndroidManifestWizard : public Utils::Wizard
{
    Q_OBJECT
public:
    CreateAndroidManifestWizard(ProjectExplorer::Target *target);

    QmakeProjectManager::QmakeProFileNode *node() const;
    void setNode(QmakeProjectManager::QmakeProFileNode *node);

    QString sourceFileName() const;

    void accept();

public slots:
    void setDirectory(const QString &directory);
private:
    void createAndroidManifestFile();
    ProjectExplorer::Target *m_target;
    QmakeProjectManager::QmakeProFileNode *m_node;
    QString m_directory;
};
}
}

#endif // CREATEANDROIDMANIFESTWIZARD_H

==> qt-creator-opensource-src-3.2.2.zip: qt-creator-opensource-src-3.2.2/src/plugins/android/createandroidmanifestwizard.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/
#ifndef CREATEANDROIDMANIFESTWIZARD_H
#define CREATEANDROIDMANIFESTWIZARD_H

#include <utils/pathchooser.h>
#include <utils/wizard.h>

QT_BEGIN_NAMESPACE
class QComboBox;
class QLabel;
QT_END_NAMESPACE

namespace ProjectExplorer { class Target; }
namespace QmakeProjectManager { class QmakeProFileNode; }

namespace Android {
namespace Internal {

class CreateAndroidManifestWizard;

class NoApplicationProFilePage : public QWizardPage
{
    Q_OBJECT
public:
    NoApplicationProFilePage(CreateAndroidManifestWizard *wizard);
private:
    CreateAndroidManifestWizard *m_wizard;
};

class ChooseProFilePage : public QWizardPage
{
    Q_OBJECT
public:
    ChooseProFilePage(CreateAndroidManifestWizard *wizard, const QList<QmakeProjectManager::QmakeProFileNode *> &nodes);
private slots:
    void nodeSelected(int index);
private:
    CreateAndroidManifestWizard *m_wizard;
    QComboBox *m_comboBox;
};

class ChooseDirectoryPage : public QWizardPage
{
    Q_OBJECT
public:
    ChooseDirectoryPage(CreateAndroidManifestWizard *wizard);
protected:
    bool isComplete() const;
private slots:
    void checkPackageSourceDir();
private:
    CreateAndroidManifestWizard *m_wizard;
    Utils::PathChooser *m_androidPackageSourceDir;
    QLabel *m_sourceDirectoryWarning;
    QLabel *m_warningIcon;
    bool m_complete;
};

class CreateAndroidManifestWizard : public Utils::Wizard
{
    Q_OBJECT
public:
    CreateAndroidManifestWizard(ProjectExplorer::Target *target);

    QmakeProjectManager::QmakeProFileNode *node() const;
    void setNode(QmakeProjectManager::QmakeProFileNode *node);

    QString sourceFileName() const;

    void accept();

public slots:
    void setDirectory(const QString &directory);
private:
    void createAndroidManifestFile();
    ProjectExplorer::Target *m_target;
    QmakeProjectManager::QmakeProFileNode *m_node;
    QString m_directory;
};
}
}

#endif // CREATEANDROIDMANIFESTWIZARD_H
